///
/// @file	     CommonReg.h
/// @copyright   Copyright (c) 2012 Toradex AG
/// @author	     $Author: gap $
/// @version     $Rev: 1138 $ 
/// @date        $Date: 2012-10-31 13:29:08 +0100 (Wed, 31 Oct 2012) $
/// @brief	     PXA & Tegra Common Register Definitions
/// 
/// @target      PXAxxx, T20
//

#ifndef __COMMON_REG_H__
#define __COMMON_REG_H__

#ifdef __cplusplus
extern "C" {
#endif


/// Register base addresses.
#define REG_BASE				0x40000000
#define PERIPH_REG_BASE			REG_BASE

/// General offset.
#define DMA_OFFSET				0x00000000		///< DMA
#define UART1_OFFSET			0x00100000		///< UART1 (FFUART)
#define UART2_OFFSET			0x00200000		///< UART2 (BTUART)
#define I2C_OFFSET				0x00301680		///< I2C
#define AC97_OFFSET				0x00500000		///< AC97
#define USBC_OFFSET				0x00600000		///< USB Client
#define UART3_OFFSET			0x00700000		///< UART3 (STUART)
#define RTC_OFFSET				0x00900000		///< RTC
#define OST_OFFSET				0x00A00000		///< OS Timer
#define PWM0_2_OFFSET			0x00B00000		///< PWM 0 and 2
#define PWM1_3_OFFSET			0x00C00000		///< PWM 1 and 3
#define PWM0_OFFSET				0x00B00000      ///< PWM0
#define PWM1_OFFSET				0x00C00000      ///< PWM1
#define PWM2_OFFSET				0x00B00010      ///< PWM2
#define PWM3_OFFSET				0x00C00010      ///< PWM3
#define INTC_OFFSET				0x00D00000		///< Interrupt Controller
#define GPIO_OFFSET				0x00E00000		///< GPIO
#define SSP1_OFFSET				0x01000000		///< SSP1
#define SD_OFFSET				0x01100000		///< MMC/SDIO
#define KP_OFFSET				0x01500000		///< Keypad
#define USIM_OFFSET				0x01600000		///< USIM
#define SSP2_OFFSET				0x01700000		///< SSP2
#define SSP3_OFFSET				0x01900000		///< SSP3
#define SSP4_OFFSET				0x01A00000		///< SSP4
#define LCD_OFFSET				0x04000000		///< LCD controller
#define USBH_OFFSET				0x0C000000		///< USB Host
#define CIF_OFFSET				0x10000000		///< Camera Interface
#define IMC_OFFSET				0x18000000		///< Internal Memory


/// PXA270 offset.
#define CLK_OFFSET_PXA270		0x01300000		///< Clock Manager
#define ARB_OFFSET_PXA270		0x08000048		///< System Bus Arbiter
#define MEM_OFFSET				0x08000000		///< Memory Controller


/// PXA3xx offset.
#define MFP_OFFSET				0x00E10000		///< Multi function pin
#define PWR_OFFSET_MH			0x00F00000		///< Power Management
#define CLK_OFFSET_MH			0x01340000		///< Clock Manager
#define OWIRE_OFFSET			0x01B00000		///< One-Wire
#define TOUCH_OFFSET			0x01C00000		///< Touch-screen
#define CIR_OFFSET				0x01D00000		///< Consumer Infrared
#define SD2_OFFSET				0x02000000		///< MMC/SDIO 2
#define USIM2_OFFSET			0x02100000		///< USIM 2
#define SD3_OFFSET				0x02500000		///< MMC/SDIO 3
#define NAND_OFFSET				0x03100000		///< NAND
#define MLCD_OFFSET				0x06000000		///< Mini LCD
#define ARB_OFFSET				0x0600FE00		///< System Bus Arbiter
#define PERFDBG_OFFSET			0x0600FF00		///< Performance Monitoring and Debug
#define DMEM_OFFSET				0x08100000		///< Dynamic Memory
#define SMEM_OFFSET				0x0A000000		///< Static Memory
#define GCU_OFFSET				0x14000000		///< 2D Accelerator
#define VCU_OFFSET				0x16000000		///< Video Accelerator

/// Tegra.
#define PWM0_OFFSET_TEG			0x3000A000      ///< PWM0
#define PWM1_OFFSET_TEG			0x3000A010      ///< PWM1
#define PWM2_OFFSET_TEG			0x3000A020      ///< PWM2
#define PWM3_OFFSET_TEG			0x3000A030      ///< PWM3
#define SLINK_SPI1_OFFSET_TEG	0x3000D400		///< SSP1
#define SLINK_SPI2_OFFSET_TEG	0x3000D600		///< SSP1
#define SLINK_SPI3_OFFSET_TEG	0x3000D800		///< SSP2
#define SLINK_SPI4_OFFSET_TEG	0x3000DA00		///< SSP3
#define SERIAL_FLASH_SPI_OFFSET_TEG	0x3000C380		///< Serial flash spi
#define I2C1_OFFSET_TEG				0x3000C000		///< I2C1
#define I2C2_OFFSET_TEG				0x3000C400		///< I2C2
#define I2C3_OFFSET_TEG				0x3000C500		///< I2C3


#ifdef __cplusplus
}
#endif

#endif  // __COMMON_REG_H__